@@ -1,9 +1,10 @@
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 from .decorators import process, validation
-from .models import ValueObject
+from .models import EnumerationValueObject, ValueObject
 
 __all__ = (
+    'EnumerationValueObject',
     'ValueObject',
     'process',
     'validation',
